from srai_core.tools_env import get_client_ecr


class EcrHelper:
    def __init__(self) -> None:
        self.ecr_client = get_client_ecr()

    def list_ecr_images(self):
        # Create an ECR client

        # Get a list of all repositories in your ECR
        repositories = self.ecr_client.describe_repositories()

        for repo in repositories["repositories"]:
            repo_name = repo["repositoryName"]
            print(f"Images in repository: {repo_name}")

            # Paginate through image details since ECR might have many images
            paginator = self.ecr_client.get_paginator("list_images")
            for page in paginator.paginate(repositoryName=repo_name):
                for image in page["imageIds"]:
                    print(
                        f"  Image: {image.get('imageTag', 'latest')} (Digest: {image['imageDigest']})"
                    )


def main():
    ecr_helper = EcrHelper()
    ecr_helper.list_ecr_images()


if __name__ == "__main__":
    main()



import os
import boto3


def read_package_info():
    pass


def get_string_from_env(env_name: str) -> str:
    value = os.environ.get(env_name)
    if value is None:
        raise Exception(f"Environment variable {env_name} is not set")
    return value


def get_client_s3() -> boto3.client:
    aws_access_key_id = get_string_from_env("AWS_ACCESS_KEY_ID")
    aws_secret_access_key = get_string_from_env("AWS_SECRET_ACCESS_KEY")
    aws_region_name = get_string_from_env("AWS_REGION_NAME")
    return boto3.client(
        "s3",
        aws_access_key_id=aws_access_key_id,
        aws_secret_access_key=aws_secret_access_key,
        region_name=aws_region_name,
    )


def get_client_ecr() -> boto3.client:
    aws_access_key_id = get_string_from_env("AWS_ACCESS_KEY_ID")
    aws_secret_access_key = get_string_from_env("AWS_SECRET_ACCESS_KEY")
    aws_region_name = get_string_from_env("AWS_REGION_NAME")
    return boto3.client(
        "ecr",
        aws_access_key_id=aws_access_key_id,
        aws_secret_access_key=aws_secret_access_key,
        region_name=aws_region_name,
    )
